==> thx_project-0.0.3.tar.gz: thx_project-0.0.3/thx/project/models.py <==
# -*- coding: utf-8 -*-

import datetime

from django.db import models
from django.utils.translation import gettext_lazy as _

from apps.organization.models import Organization, Contact
from thx.core.models import UserModel, DateModel, StatusModel, OrderedModel, CleanModel


class ProjectType(CleanModel, UserModel, DateModel, StatusModel, OrderedModel):
    name = models.CharField(
        max_length=255,
        unique=True,
        verbose_name=_('name'),
    )
    slug = models.SlugField(
        max_length=255,
        unique=True,
        verbose_name=_('slug'),
    )
    description = models.TextField(
        blank=True,
        verbose_name=_('description'),
    )

    class Meta:
        verbose_name = _('project type')
        verbose_name_plural = _('project types')
        ordering = ('ordering',)
        permissions = (
            ("list_projecttype", "Can list project type"),
            ("detail_projecttype", "Can detail project type"),
            ("enable_projecttype", "Can enable project type"),
            ("disable_projecttype", "Can disable project type"),
        )

    def __str__(self):
        return self.name


class Project(CleanModel, UserModel, DateModel, StatusModel, OrderedModel):
    organization = models.ForeignKey(
        Organization,
        on_delete=models.PROTECT,
        related_name='projects',
        verbose_name=_('organization'),
    )
    project_type = models.ForeignKey(
        ProjectType,
        on_delete=models.PROTECT,
        related_name='projects',
        verbose_name=_('project type'),
    )
    name = models.CharField(
        max_length=255,
        verbose_name=_('name'),
    )
    description = models.TextField(
        blank=True,
        verbose_name=_('description'),
    )
    date_start = models.DateField(
        db_index=True,
        default=datetime.date.today,
        verbose_name=_('start date'),
    )
    date_end = models.DateField(
        blank=True, null=True,
        db_index=True,
        verbose_name=_('end date'),
    )
    number = models.IntegerField(
        blank=True, null=True,
        db_index=True,
        verbose_name=_("number"),
        db_column="pnumber",
    )

    class Meta:
        verbose_name = _('project')
        verbose_name_plural = _('projects')
        ordering = ('ordering', 'name',)
        permissions = (
            ("list_project", "Can list project"),
            ("detail_project", "Can detail project"),
            ("enable_project", "Can enable project"),
            ("disable_project", "Can disable project"),
        )

    def __str__(self):
        return self.name

    @property
    def organization_name(self):
        return self.organization.name


class ProjectNumber(CleanModel, UserModel, DateModel, OrderedModel):
    year = models.IntegerField(
        unique=True,
        verbose_name=_("year"),
    )

    last_date = models.DateField(
        verbose_name=_("last date"),
    )

    last_number = models.IntegerField(
        blank=True, null=True,
        verbose_name=_("last number"),
    )

    class Meta:
        verbose_name = _('project number')
        verbose_name_plural = _('project numbers')
        ordering = ('ordering',)
        permissions = (
            ("list_projectnumber", "Can list project number"),
            ("detail_projectnumber", "Can detail project number"),
            ("enable_projectnumber", "Can enable project number"),
            ("disable_projectnumber", "Can disable project number"),
        )

    def __str__(self):
        return f"{self.year} {self.last_number}"

==> thx_project-0.1.0.tar.gz: thx_project-0.1.0/thx/project/models.py <==
# -*- coding: utf-8 -*-

import datetime

from apps.organization.models import Organization
from django.db import models
from django.utils.translation import gettext_lazy as _
from thx.core.models import CleanModel, DateModel, OrderedModel, StatusModel, UserModel


class ProjectType(CleanModel, UserModel, DateModel, StatusModel, OrderedModel):
    name = models.CharField(
        max_length=255,
        unique=True,
        verbose_name=_('name'),
    )
    slug = models.SlugField(
        max_length=255,
        unique=True,
        verbose_name=_('slug'),
    )
    description = models.TextField(
        blank=True,
        verbose_name=_('description'),
    )

    class Meta:
        verbose_name = _('project type')
        verbose_name_plural = _('project types')
        ordering = ('ordering',)
        permissions = (
            ("list_projecttype", "Can list project type"),
            ("detail_projecttype", "Can detail project type"),
            ("enable_projecttype", "Can enable project type"),
            ("disable_projecttype", "Can disable project type"),
        )

    def __str__(self):
        return self.name


class Project(CleanModel, UserModel, DateModel, StatusModel, OrderedModel):
    organization = models.ForeignKey(
        Organization,
        on_delete=models.PROTECT,
        related_name='projects',
        verbose_name=_('organization'),
    )
    project_type = models.ForeignKey(
        ProjectType,
        on_delete=models.PROTECT,
        related_name='projects',
        verbose_name=_('project type'),
    )
    name = models.CharField(
        max_length=255,
        verbose_name=_('name'),
    )
    description = models.TextField(
        blank=True,
        verbose_name=_('description'),
    )
    date_start = models.DateField(
        db_index=True,
        default=datetime.date.today,
        verbose_name=_('start date'),
    )
    date_end = models.DateField(
        blank=True, null=True,
        db_index=True,
        verbose_name=_('end date'),
    )
    number = models.IntegerField(
        blank=True, null=True,
        db_index=True,
        verbose_name=_("number"),
        db_column="pnumber",
    )

    class Meta:
        verbose_name = _('project')
        verbose_name_plural = _('projects')
        ordering = ('ordering', 'name',)
        permissions = (
            ("list_project", "Can list project"),
            ("detail_project", "Can detail project"),
            ("enable_project", "Can enable project"),
            ("disable_project", "Can disable project"),
        )

    def __str__(self):
        return self.name

    @property
    def organization_name(self):
        return self.organization.name


class ProjectNumber(CleanModel, UserModel, DateModel, OrderedModel):
    year = models.IntegerField(
        unique=True,
        verbose_name=_("year"),
    )

    last_date = models.DateField(
        verbose_name=_("last date"),
    )

    last_number = models.IntegerField(
        blank=True, null=True,
        verbose_name=_("last number"),
    )

    class Meta:
        verbose_name = _('project number')
        verbose_name_plural = _('project numbers')
        ordering = ('ordering',)
        permissions = (
            ("list_projectnumber", "Can list project number"),
            ("detail_projectnumber", "Can detail project number"),
            ("enable_projectnumber", "Can enable project number"),
            ("disable_projectnumber", "Can disable project number"),
        )

    def __str__(self):
        return f"{self.year} {self.last_number}"
